@@ -674,12 +674,14 @@ class AsyncClient:
 
     # deprecated: use stream_spot_orderbook_snapshot
     async def stream_spot_orderbook(self, market_id: str):
-        return self.stream_spot_orderbook_snapshot(market_ids=[market_id])
+        req = spot_exchange_rpc_pb.StreamOrderbookRequest(market_ids=[market_id])
+        metadata = await self.load_cookie(type="exchange")
+        return self.stubSpotExchange.StreamOrderbook.__call__(req, metadata=metadata)
 
     async def stream_spot_orderbook_snapshot(self, market_ids: List[str]):
-        req = spot_exchange_rpc_pb.StreamOrderbookSnapshotRequest(market_ids=market_ids)
+        req = spot_exchange_rpc_pb.StreamOrderbookV2Request(market_ids=market_ids)
         metadata = await self.load_cookie(type="exchange")
-        return self.stubSpotExchange.StreamOrderbookSnapshot.__call__(req, metadata=metadata)
+        return self.stubSpotExchange.StreamOrderbookV2.__call__(req, metadata=metadata)
 
     async def stream_spot_orderbook_update(self, market_ids: List[str]):
         req = spot_exchange_rpc_pb.StreamOrderbookUpdateRequest(market_ids=market_ids)
@@ -829,12 +831,16 @@ class AsyncClient:
 
     # deprecated: use stream_derivative_orderbook_snapshot
     async def stream_derivative_orderbook(self, market_id: str):
-        return self.stream_derivative_orderbook_snapshot(market_ids=[market_id])
+        req = derivative_exchange_rpc_pb.StreamOrderbookRequest(market_ids=[market_id])
+        metadata = await self.load_cookie(type="exchange")
+        return self.stubDerivativeExchange.StreamOrderbook.__call__(
+            req, metadata=metadata
+        )
 
     async def stream_derivative_orderbook_snapshot(self, market_ids: List[str]):
-        req = derivative_exchange_rpc_pb.StreamOrderbookSnapshotRequest(market_ids=market_ids)
+        req = derivative_exchange_rpc_pb.StreamOrderbookV2Request(market_ids=market_ids)
         metadata = await self.load_cookie(type="exchange")
-        return self.stubDerivativeExchange.StreamOrderbookSnapshot.__call__(
+        return self.stubDerivativeExchange.StreamOrderbookV2.__call__(
             req, metadata=metadata
         )
 
